@@ -2,7 +2,7 @@ import numpy as np
 from bigstream import features
 from bigstream import ransac
 import dask.array as da
-from ClusterWrap.clusters import janelia_lsf_cluster
+import ClusterWrap
 
 WORKER_BUFFER = 8
 
@@ -17,21 +17,37 @@ def ransac_affine(
     nspots=5000,
     align_threshold=2.0,
     num_sigma_max=10,
+    verbose=True,
+    fixed_spots=None,
+    moving_spots=None,
+    **kwargs,
 ):
     """
     """
 
+    if verbose:
+        print('Getting key points')
+
     # get spots
-    fixed_spots = features.blob_detection(
-        fixed, min_radius, max_radius,
-        num_sigma=max(max_radius-min_radius, num_sigma_max),
-        threshold=0, exclude_border=cc_radius,
-    )
-    moving_spots = features.blob_detection(
-        moving, min_radius, max_radius,
-        num_sigma=max(max_radius-min_radius, num_sigma_max),
-        threshold=0, exclude_border=cc_radius,
-    )
+    if fixed_spots is None:
+        fixed_spots = features.blob_detection(
+            fixed, min_radius, max_radius,
+            num_sigma=max(max_radius-min_radius, num_sigma_max),
+            threshold=0, exclude_border=cc_radius,
+        )
+        if verbose:
+            ns = fixed_spots.shape[0]
+            print(f'FIXED image: found {ns} key points')
+
+    if moving_spots is None:
+        moving_spots = features.blob_detection(
+            moving, min_radius, max_radius,
+            num_sigma=max(max_radius-min_radius, num_sigma_max),
+            threshold=0, exclude_border=cc_radius,
+        )
+        if verbose:
+            ns = moving_spots.shape[0]
+            print(f'MOVING image: found {ns} key points')
 
     # sort
     sort_idx = np.argsort(fixed_spots[:, 3])[::-1]
@@ -60,9 +76,13 @@ def ransac_affine(
         correlations, match_threshold,
     )
 
+    if verbose:
+        ns = fixed_spots.shape[0]
+        print(f'MATCHED points: found {ns} matched points')
+
     # align
     return ransac.ransac_align_points(
-        fixed_spots, moving_spots, align_threshold,
+        fixed_spots, moving_spots, align_threshold, **kwargs,
     )
 
 
@@ -93,7 +113,7 @@ def tiled_ransac_affine(
     overlap = [int(round(x/8)) for x in blocksize]
 
     # distributed computations done in cluster context
-    with janelia_lsf_cluster(**cluster_kwargs) as cluster:
+    with ClusterWrap.cluster(**cluster_kwargs) as cluster:
         cluster.scale_cluster(nblocks + WORKER_BUFFER)
 
         # wrap images as dask arrays
